@@ -38,14 +38,13 @@ static void gtk_html_a11y_init       (GtkHTMLA11Y *a11y);
 
 static GtkAccessibleClass *parent_class = NULL;
 
-
 static gint
 get_n_actions (AtkAction *action)
 {
 	return 1;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 get_description (AtkAction *action, gint i)
 {
 	if (i == 0)
@@ -54,7 +53,7 @@ get_description (AtkAction *action, gint i)
 	return NULL;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 action_get_name (AtkAction *action, gint i)
 {
 	if (i == 0)
@@ -63,15 +62,17 @@ action_get_name (AtkAction *action, gint i)
 	return NULL;
 }
 
-
-
 static gboolean
 do_action (AtkAction * action, gint i)
 {
 	GtkWidget *widget;
 	gboolean return_value = TRUE;
 
+#if GTK_CHECK_VERSION(2,21,0)
+	widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (action));
+#else
 	widget = GTK_ACCESSIBLE (action)->widget;
+#endif
 
 	if (widget == NULL) {
 	/*
@@ -80,10 +81,9 @@ do_action (AtkAction * action, gint i)
 	return FALSE;
 	}
 
-	if (!GTK_WIDGET_SENSITIVE (widget) || !GTK_WIDGET_VISIBLE (widget))
+	if (!gtk_widget_get_sensitive (widget) || !gtk_widget_get_visible (widget))
 		return FALSE;
 
-
 	switch (i) {
 	case 0:
 		gtk_widget_grab_focus (widget);
@@ -169,7 +169,6 @@ gtk_html_a11y_initialize (AtkObject *obj, gpointer data)
 	g_object_set_data (G_OBJECT (obj), GTK_HTML_ID, data);
 }
 
-
 static gint
 gtk_html_a11y_get_n_children (AtkObject *accessible)
 {
@@ -202,7 +201,6 @@ gtk_html_a11y_get_n_children (AtkObject *accessible)
 		n_children = html_object_get_n_children (GTK_HTML_A11Y_GTKHTML (accessible)->engine->clue);
 	}
 
-
 	/* printf ("gtk_html_a11y_get_n_children resolves to %d\n", n_children); */
 
 	return n_children;
@@ -249,7 +247,7 @@ gtk_html_a11y_ref_child (AtkObject *accessible, gint index)
 	return accessible_child;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 gtk_html_a11y_get_name (AtkObject *obj)
 {
 	if (obj->name != NULL) {
@@ -310,7 +308,6 @@ gtk_html_a11y_grab_focus_cb(GtkWidget * widget)
 {
         AtkObject *focus_object, *obj, *clue;
 
-
 	focus_object = gtk_html_a11y_get_focus_object (widget);
 	if (focus_object == NULL)
 		return;
@@ -327,41 +324,37 @@ gtk_html_a11y_grab_focus_cb(GtkWidget * widget)
 static void
 gtk_html_a11y_cursor_changed_cb (GtkWidget *widget)
 {
-        AtkObject *focus_object, *obj;
+	AtkObject *focus_object;
 
 	focus_object = gtk_html_a11y_get_focus_object (widget);
 	g_return_if_fail (focus_object != NULL);
-	obj = gtk_widget_get_accessible (widget);
 
 	if (gtk_html_a11y_focus_object != focus_object) {
 		gtk_html_a11y_focus_object = focus_object;
-        	atk_focus_tracker_notify (focus_object);
+		atk_focus_tracker_notify (focus_object);
 	} else {
 		if (G_IS_HTML_A11Y_TEXT(focus_object)) {
 			gint offset;
 
 			offset = (GTK_HTML(widget))->engine->cursor->offset;
 			g_signal_emit_by_name(focus_object, "text_caret_moved",offset);
-                }
-        }
+		}
+	}
 }
 
 static void
-gtk_html_a11y_insert_object_cb (GtkWidget * widget, int pos, int len)
+gtk_html_a11y_insert_object_cb (GtkWidget * widget, gint pos, gint len)
 {
-	AtkObject * a11y, *obj;
-
+	AtkObject * a11y;
 
 	HTMLCursor *cursor = GTK_HTML (widget)->engine->cursor;
 
-
-        obj = gtk_widget_get_accessible (widget);
 	a11y = gtk_html_a11y_get_focus_object (widget);
 	g_return_if_fail (a11y != NULL);
 
 	if (gtk_html_a11y_focus_object != a11y) {
 		gtk_html_a11y_focus_object = a11y;
-        	atk_focus_tracker_notify (a11y);
+		atk_focus_tracker_notify (a11y);
 	}
 
 	if (G_IS_HTML_A11Y_TEXT(a11y)) {
@@ -371,17 +364,16 @@ gtk_html_a11y_insert_object_cb (GtkWidget * widget, int pos, int len)
 }
 
 static void
-gtk_html_a11y_delete_object_cb (GtkWidget * widget, int pos, int len)
+gtk_html_a11y_delete_object_cb (GtkWidget * widget, gint pos, gint len)
 {
-	AtkObject * a11y, *obj;
+	AtkObject * a11y;
 
-        obj = gtk_widget_get_accessible (widget);
 	a11y = gtk_html_a11y_get_focus_object (widget);
 	g_return_if_fail (a11y != NULL);
 
 	if (gtk_html_a11y_focus_object != a11y) {
 		gtk_html_a11y_focus_object = a11y;
-        	atk_focus_tracker_notify (a11y);
+		atk_focus_tracker_notify (a11y);
 	}
 
 	if (G_IS_HTML_A11Y_TEXT(a11y)) {
