@@ -80,7 +80,7 @@ struct _GtkHTMLClass {
 	void (* set_base_target) (GtkHTML *html, const gchar *base_url);
 
 	void (* on_url)		 (GtkHTML *html, const gchar *url);
-	void (* redirect)        (GtkHTML *html, const gchar *url, int delay);
+	void (* redirect)        (GtkHTML *html, const gchar *url, gint delay);
 	void (* submit)          (GtkHTML *html, const gchar *method, const gchar *url, const gchar *encoding);
 	gboolean (* object_requested)(GtkHTML *html, GtkHTMLEmbedded *);
 
@@ -99,8 +99,8 @@ struct _GtkHTMLClass {
 	void     (* cursor_move)          (GtkHTML *html, GtkDirectionType dir_type, GtkHTMLCursorSkipType skip);
 	gboolean (* command)              (GtkHTML *html, GtkHTMLCommandType com_type);
 	void (* cursor_changed)       (GtkHTML *html);
-	void (* object_inserted)       (GtkHTML *html, int pos, int len);
-	void (* object_delete)        (GtkHTML *html, int pos, int len);
+	void (* object_inserted)       (GtkHTML *html, gint pos, gint len);
+	void (* object_delete)        (GtkHTML *html, gint pos, gint len);
 
 	/* properties */
 	GtkHTMLClassProperties *properties;
@@ -154,17 +154,18 @@ void                       gtk_html_select_line                   (GtkHTML
 void                       gtk_html_select_paragraph              (GtkHTML                   *html);
 void                       gtk_html_select_paragraph_extended     (GtkHTML                   *html);
 void                       gtk_html_select_all                    (GtkHTML                   *html);
+void                       gtk_html_unselect_all                  (GtkHTML                   *html);
 /* Loading.  */
 GtkHTMLStream             *gtk_html_begin                         (GtkHTML                   *html);
 GtkHTMLStream             *gtk_html_begin_full                    (GtkHTML                   *html,
-								   char                      *target_frame,
-								   const char                *content_type,
+								   gchar                      *target_frame,
+								   const gchar                *content_type,
 								   GtkHTMLBeginFlags         flags);
 
 void                       gtk_html_write                         (GtkHTML                   *html,
 								   GtkHTMLStream             *handle,
 								   const gchar               *buffer,
-								   size_t                     size);
+								   gsize                     size);
 void                       gtk_html_end                           (GtkHTML                   *html,
 								   GtkHTMLStream             *handle,
 								   GtkHTMLStreamStatus        status);
@@ -176,13 +177,13 @@ void                       gtk_html_load_from_string              (GtkHTML
 
 /* Saving.  */
 gboolean                   gtk_html_export                        (GtkHTML                   *html,
-								   const char                *type,
+								   const gchar                *type,
 								   GtkHTMLSaveReceiverFn      receiver,
 								   gpointer                   data);
-char *                     gtk_html_get_selection_html            (GtkHTML                   *html,
-								   int                       *len);
-char *                     gtk_html_get_selection_plain_text      (GtkHTML                   *html,
-								   int                       *len);
+gchar *                     gtk_html_get_selection_html            (GtkHTML                   *html,
+								   gint                       *len);
+gchar *                     gtk_html_get_selection_plain_text      (GtkHTML                   *html,
+								   gint                       *len);
 
 /* Editable support.  */
 void                       gtk_html_set_editable                  (GtkHTML                   *html,
@@ -204,7 +205,7 @@ void                       gtk_html_set_caret_mode                (GtkHTML
 gboolean                   gtk_html_get_caret_mode                (const GtkHTML             *html);
 
 void			   gtk_html_set_caret_first_focus_anchor  (GtkHTML		     *html,
-								   const char                *name);
+								   const gchar                *name);
 
 /* Animated Images */
 void                       gtk_html_set_animate                   (GtkHTML                   *html,
@@ -212,18 +213,18 @@ void                       gtk_html_set_animate                   (GtkHTML
 gboolean                   gtk_html_get_animate                   (const GtkHTML             *html);
 
 /* Printing support.  */
-void 			   gtk_html_print_page_with_header_footer (GtkHTML		     *html,
-								   GtkPrintContext 	     *context,
-			   					   gdouble		      header_height,
+void			   gtk_html_print_page_with_header_footer (GtkHTML		     *html,
+								   GtkPrintContext	     *context,
+								   gdouble		      header_height,
 								   gdouble		      footer_height,
 								   GtkHTMLPrintCallback       header_print,
-							           GtkHTMLPrintCallback       footer_print,
-								   gpointer 		      user_data);
+								   GtkHTMLPrintCallback       footer_print,
+								   gpointer		      user_data);
 void			   gtk_html_print_page			   (GtkHTML		      *html,
 								    GtkPrintContext	      *context);
-gint 			   gtk_html_print_page_get_pages_num 	  (GtkHTML		      *html,
+gint			   gtk_html_print_page_get_pages_num	  (GtkHTML		      *html,
 								   GtkPrintContext            *context,
-					 			   gdouble		       header_height,
+								   gdouble		       header_height,
 								   gdouble                     footer_height);
 GtkPrintOperationResult	   gtk_html_print_operation_run		  (GtkHTML                    *html,
 								   GtkPrintOperation          *operation,
@@ -238,7 +239,7 @@ GtkPrintOperationResult	   gtk_html_print_operation_run		  (GtkHTML
 
 /* Title.  */
 const gchar               *gtk_html_get_title                     (GtkHTML                   *html);
-void                       gtk_html_set_title                     (GtkHTML                   *html, const char *title);
+void                       gtk_html_set_title                     (GtkHTML                   *html, const gchar *title);
 
 /* Anchors.  */
 gboolean                   gtk_html_jump_to_anchor                (GtkHTML                   *html,
@@ -281,9 +282,9 @@ void                       gtk_html_append_html                   (GtkHTML
 /* misc utils */
 gpointer                   gtk_html_get_object_by_id              (GtkHTML                   *html,
 								   const gchar               *id);
-const char *               gtk_html_get_object_id_at              (GtkHTML                   *html,
-								   int                        x,
-								   int                        y);
+const gchar *               gtk_html_get_object_id_at              (GtkHTML                   *html,
+								   gint                        x,
+								   gint                        y);
 gboolean                   gtk_html_command                       (GtkHTML                   *html,
 								   const gchar               *command_name);
 gboolean                   gtk_html_edit_make_cursor_visible      (GtkHTML                   *html);
@@ -298,13 +299,13 @@ void                       gtk_html_set_allow_frameset            (GtkHTML
 								   gboolean                   allow);
 gboolean                   gtk_html_get_allow_frameset            (GtkHTML                   *html);
 void                       gtk_html_set_base                      (GtkHTML                   *html,
-								   const char                *url);
-const char                *gtk_html_get_base                      (GtkHTML                   *html);
-char                      *gtk_html_get_url_base_relative         (GtkHTML                   *html,
-								   const char                *url);
-char                      *gtk_html_get_url_object_relative       (GtkHTML                   *html,
+								   const gchar                *url);
+const gchar                *gtk_html_get_base                      (GtkHTML                   *html);
+gchar                      *gtk_html_get_url_base_relative         (GtkHTML                   *html,
+								   const gchar                *url);
+gchar                      *gtk_html_get_url_object_relative       (GtkHTML                   *html,
 								   HTMLObject                *o,
-								   const char                *url);
+								   const gchar                *url);
 void                       gtk_html_images_ref                    (GtkHTML                   *html);
 void                       gtk_html_images_unref                  (GtkHTML                   *html);
 void                       gtk_html_image_ref                     (GtkHTML                   *html,
@@ -319,23 +320,25 @@ void                       gtk_html_set_images_blocking           (GtkHTML
 								   gboolean                   block);
 gboolean                   gtk_html_has_undo                      (GtkHTML                   *html);
 void                       gtk_html_drop_undo                     (GtkHTML                   *html);
-char *                     gtk_html_get_url_at                    (GtkHTML                   *html,
-								   int                        x,
-								   int                        y);
-char *                     gtk_html_get_cursor_url                (GtkHTML                   *html);
+gchar *                     gtk_html_get_url_at                    (GtkHTML                   *html,
+								   gint                        x,
+								   gint                        y);
+gchar *                     gtk_html_get_cursor_url                (GtkHTML                   *html);
 
-char *                     gtk_html_get_image_src_at              (GtkHTML                   *html,
-								   int                        x,
-								   int                        y);
-char *                     gtk_html_get_cursor_image_src          (GtkHTML                   *html);
+gchar *                     gtk_html_get_image_src_at              (GtkHTML                   *html,
+								   gint                        x,
+								   gint                        y);
+gchar *                     gtk_html_get_cursor_image_src          (GtkHTML                   *html);
 
 void                       gtk_html_set_tokenizer                 (GtkHTML                   *html,
 								   HTMLTokenizer             *tokenizer);
 
+gboolean		   gtk_html_get_cursor_pos		  (GtkHTML *html, gint *position, gint *offset);
+
 /* DEPRECATED */
 #if 1
 gboolean                   gtk_html_build_with_gconf              (void);
-const gchar*               gtk_html_get_default_content_type              (GtkHTML                   *html);
+const gchar *               gtk_html_get_default_content_type              (GtkHTML                   *html);
 void                       gtk_html_set_default_content_type              (GtkHTML                   *html,
 								   const gchar                     *content_type);
 void			   gtk_html_set_default_engine		  (GtkHTML *html,
